camelot.camelot.view.controls.inheritance

Package camelot :: Package camelot :: Package view :: Package controls :: Module inheritance |
[hide private]
[frames] | no frames]

# Module inheritance

source code

Controls related to visualizing object hierarchy

Classes | [hide private]
| SubclassItem
| SubclassTree Widget to select subclasses of a certain entity, where the subclasses are represented in a tree

Variables | [hide private]
| logger = `logging.getLogger('camelot.view.controls.inheritance')`
| QT_MAJOR_VERSION = `float('.'.join(str(QtCore.QT_VERSION_STR).s`...``

Variables Details | [hide private]

  ### QT_MAJOR_VERSION Value:
      float('.'.join(str(QtCore.QT_VERSION_STR).split('.') [0: 2]))